Crate rodarte_minigrep

Crate rodarte_minigrep 

Minigrep

A library to perform simple text searching against a string content target.

Structs

Config
Main structure that holds the data required for the process to work.

Functions

run
Entrypoint function that bootstraps the searching application using a Config instance.
search
Performs a case-sensitive search of a query string against a target contents string, returning a vector with the matching lines.
search_case_insensitive
Performs a case-insensitive search of a query string against a target contents string, returning a vector with the matching lines.