Minigrep
A library to perform simple text searching against a string content target.
Structs
- Config
- Main structure that holds the data required for the process to work.
Functions
- run
- Entrypoint function that bootstraps the searching application using a
Configinstance. - search
- Performs a case-sensitive search of a
querystring against a targetcontentsstring, returning a vector with the matching lines. - search_
case_ insensitive - Performs a case-insensitive search of a
querystring against a targetcontentsstring, returning a vector with the matching lines.